@@ -213,7 +213,7 @@ class ExpaiProject:
 
     def create_sample(self, sample_path: str = None, sample_name: str = None, sample_separator: str = None, sample_target_col: str = None,
                       sample_encoding: str = 'utf-8', is_display = False, reference_sample_id: str = None, reference_sample_name: str = None,
-                      display_sample_id: str = None, display_sample_name: str = None):
+                      display_sample_id: str = None, display_sample_name: str = None, sample_summary: str = None):
         """
         Create a new sample for the project
         :param sample_target_col: target column for the model
@@ -246,7 +246,8 @@ class ExpaiProject:
                 "sample_target_col": sample_target_col,
                 "is_display": 1 if is_display is True else 0,
                 "original_sample_id": reference_sample_id,
-                "display_sample_id": display_sample_id}
+                "display_sample_id": display_sample_id,
+                'sample_summary_des': sample_summary}
 
         files = {'sample_file': open(sample_path, 'r', encoding=sample_encoding)}
 
