@@ -5,7 +5,7 @@ from expai.utils import generate_response
 
 
 class ExpaiLogin:
-    def __init__(self, email: str = None, user_pass: str = None, api_key: str = None, server_name: str = "http://127.0.0.1:5000"):
+    def __init__(self, email: str = None, user_pass: str = None, api_key: str = None, server_name: str = "http://api.expai.io:80"):
         assert api_key is not None, "You must provide an api_key"
         assert email is not None, "Please, introduce your user id"
         assert user_pass is not None, "Please, introduce your password"
@@ -61,15 +61,18 @@ class ExpaiLogin:
             return generate_response(response, ['projects'])
 
 
-    def create_project(self, project_name: str = None):
+    def create_project(self, project_name: str = None, project_description: str = None):
         """
         Create a new project
         :param project_id: Name for the project
+        :param project_description: Description for the project
         :return: True if successful
         """
         assert project_name is not None, "Please, introduce a project_id"
 
-        payload = {"project_name_des": project_name}
+        payload = {"project_name_des": project_name,
+                   'project_description_des': project_description}
+
         response = self.sess.request("GET", self.server_name + "/api/projects/create", headers=self.headers,
                                      json=payload)
 
